@@ -7,9 +7,10 @@ kcv.plr <-
     if (!is.factor(y)) {
       y <- factor(y)
     } 
-    if (length(unique(y)) == 1L)
+    if (length(unique(y)) == 1L) {
       stop("Input 'y' must contain some variation (i.e., cannot contain \n
            only a single type of label).")
+    }
     if (is.null(nfolds)) {
       nfolds <- 10
     } else {
@@ -56,6 +57,10 @@ kcv.plr <-
         if (family == "binomial") {
           threshold <- (table(y) / length(y))[1]
         }
+      } else {
+        if (family == "binomial") {
+          threshold <- (table(y) / length(y))[1]
+        }
       }
       stor.cvm <- rep(NA, lalpha)
       stor.minlam <- rep(NA, lalpha)
